var searchData=
[
  ['k_0',['K',['../namespacecom_1_1sun_1_1star_1_1awt_1_1Key.html#a19359316f58dda97c1ab163e3a7b0dbd',1,'com::sun::star::awt::Key']]],
  ['k_5fcjkunifiedideographsextensiona_1',['k_CJKUnifiedIdeographsExtensionA',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29aebe236c8ec366e9c6b29510d865b424d',1,'com::sun::star::i18n']]],
  ['kalphabeticpresentation_2',['kAlphabeticPresentation',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29ae777fbfe6160bd1de11d722d00cb5c32',1,'com::sun::star::i18n']]],
  ['karabic_3',['kArabic',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a8707ba89bdb38755f3a454216a0f1ddf',1,'com::sun::star::i18n']]],
  ['karabicpresentationa_4',['kArabicPresentationA',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29ad12e7ef881d95962ad609d488248cc70',1,'com::sun::star::i18n']]],
  ['karabicpresentationb_5',['kArabicPresentationB',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a191c8ec5960762d483a5b8ef2994ad72',1,'com::sun::star::i18n']]],
  ['karmenian_6',['kArmenian',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a56b147d974b8d5fa5c87f877a3b1b5b7',1,'com::sun::star::i18n']]],
  ['karrow_7',['kArrow',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a7b131996fe213e55d8fcd2f6e4a459a2',1,'com::sun::star::i18n']]],
  ['katakana_5fhiragana_8',['KATAKANA_HIRAGANA',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a436afb2c972c4d40d888b71482e93020ae751e8e72946b16ba403fcd9e684eaf4',1,'com::sun::star::i18n']]],
  ['kbasiclatin_9',['kBasicLatin',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a8662f6729f1a48d61ab470f319a3d4c1',1,'com::sun::star::i18n']]],
  ['kbengali_10',['kBengali',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a56cd9e3e38f445c31d49c006146738b6',1,'com::sun::star::i18n']]],
  ['kblockelement_11',['kBlockElement',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29ac86edbbfe1ca37df5b2d660bdd3af42b',1,'com::sun::star::i18n']]],
  ['kbopomofo_12',['kBopomofo',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a7dec191d354e503b9a0c6d0b34e5a572',1,'com::sun::star::i18n']]],
  ['kbopomofoextended_13',['kBopomofoExtended',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a839d0ee1ba8909e1de98c6fcf68a18ae',1,'com::sun::star::i18n']]],
  ['kboxdrawing_14',['kBoxDrawing',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a9859c5caa4900dd22dc6e0a27787d7a6',1,'com::sun::star::i18n']]],
  ['kbraillepatterns_15',['kBraillePatterns',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29ae9a3ee9bceefcdcb13b39e1fadcf2423',1,'com::sun::star::i18n']]],
  ['kcharactertype_2eidl_16',['KCharacterType.idl',['../KCharacterType_8idl.html',1,'']]],
  ['kcherokee_17',['kCherokee',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a9b979de93bd54ffb45dfabef4d6639d4',1,'com::sun::star::i18n']]],
  ['kcjkcompatibility_18',['kCJKCompatibility',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a84a7af40132ae0dab44ade4dad64ea3f',1,'com::sun::star::i18n']]],
  ['kcjkcompatibilityform_19',['kCJKCompatibilityForm',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a48f7cf8f275b7fa1ffb0c1a948119cba',1,'com::sun::star::i18n']]],
  ['kcjkcompatibilityideograph_20',['kCJKCompatibilityIdeograph',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a460f8a41802c5a534a3d6b4f5cd8a60d',1,'com::sun::star::i18n']]],
  ['kcjkradicalssupplement_21',['kCJKRadicalsSupplement',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a6f1243d030ff7f76a8bd7b6c2c631e27',1,'com::sun::star::i18n']]],
  ['kcjksymbolpunctuation_22',['kCJKSymbolPunctuation',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29aa86681a01c9e76ff427812235514b60d',1,'com::sun::star::i18n']]],
  ['kcjkunifiedideograph_23',['kCJKUnifiedIdeograph',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29ac57c3b51e38c06747b74609aacf99787',1,'com::sun::star::i18n']]],
  ['kcombiningdiacritical_24',['kCombiningDiacritical',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a609afd971eec506fcbcd13ca252ebbaa',1,'com::sun::star::i18n']]],
  ['kcombininghalfmark_25',['kCombiningHalfMark',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a8a6392bc46f115af89b645456e406c59',1,'com::sun::star::i18n']]],
  ['kcontrolpicture_26',['kControlPicture',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a2a0e0c3180f0757085503e97cf4cb939',1,'com::sun::star::i18n']]],
  ['kcurrencysymbolscript_27',['kCurrencySymbolScript',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29acd2212bdc0274ae8c1c5a505a16e5b91',1,'com::sun::star::i18n']]],
  ['kcyrillic_28',['kCyrillic',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a2be8dcc7406c934e588ceefe5893448b',1,'com::sun::star::i18n']]],
  ['kdevanagari_29',['kDevanagari',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a49fe0f719f599218a2d7a005cbc74a44',1,'com::sun::star::i18n']]],
  ['kdingbat_30',['kDingbat',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29acfdf9bb31949a76f6c6f21b44a2ac76d',1,'com::sun::star::i18n']]],
  ['keep_31',['KEEP',['../namespacecom_1_1sun_1_1star_1_1ucb_1_1NameClash.html#a28e859852ecabe5a1de9e0d2d9a69df3',1,'com::sun::star::ucb::NameClash']]],
  ['keepformats_32',['KeepFormats',['../servicecom_1_1sun_1_1star_1_1sheet_1_1DatabaseRange.html#ac34b74170aee53aa1f3898b38f5ac393',1,'com::sun::star::sheet::DatabaseRange']]],
  ['keeptogether_33',['KeepTogether',['../interfacecom_1_1sun_1_1star_1_1report_1_1XSection.html#a8d835b5db9271067f775fd2d7493c3b9',1,'com::sun::star::report::XSection::KeepTogether()'],['../servicecom_1_1sun_1_1star_1_1text_1_1TextTable.html#a8d835b5db9271067f775fd2d7493c3b9',1,'com::sun::star::text::TextTable::KeepTogether()'],['../interfacecom_1_1sun_1_1star_1_1report_1_1XGroup.html#a8c23ee90f1673324ebe9be853d698d0b',1,'com::sun::star::report::XGroup::KeepTogether()']]],
  ['keeptogether_2eidl_34',['KeepTogether.idl',['../KeepTogether_8idl.html',1,'']]],
  ['kenclosedalphanumeric_35',['kEnclosedAlphanumeric',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a9cc4022bbb05d394f6c58db7596464d0',1,'com::sun::star::i18n']]],
  ['kenclosedcjklettermonth_36',['kEnclosedCJKLetterMonth',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29ac91cc150a9f0e68c0a2668eda40af086',1,'com::sun::star::i18n']]],
  ['kerning_37',['Kerning',['../structcom_1_1sun_1_1star_1_1awt_1_1FontDescriptor.html#aa6eda54d871903b98a22c0b1db0630f7',1,'com::sun::star::awt::FontDescriptor']]],
  ['kethiopic_38',['kEthiopic',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a91d1f1fe85676927cd8bf0c9663162f3',1,'com::sun::star::i18n']]],
  ['key_39',['Key',['../servicecom_1_1sun_1_1star_1_1sdbcx_1_1Key.html',1,'com::sun::star::sdbcx']]],
  ['key_40',['KEY',['../namespacecom_1_1sun_1_1star_1_1registry.html#a096c2bade01504c38ba808bfeadff2b2a147e71049e3285d642d0d5268dba260f',1,'com::sun::star::registry']]],
  ['key_2eidl_41',['Key.idl',['../sdbcx_2Key_8idl.html',1,'(Global Namespace)'],['../awt_2Key_8idl.html',1,'(Global Namespace)']]],
  ['key_5fagreement_42',['KEY_AGREEMENT',['../namespacecom_1_1sun_1_1star_1_1security_1_1KeyUsage.html#aa122bee0e332805fdeba43e6d951c17e',1,'com::sun::star::security::KeyUsage']]],
  ['key_5fcert_5fsign_43',['KEY_CERT_SIGN',['../namespacecom_1_1sun_1_1star_1_1security_1_1KeyUsage.html#a463ae94ba5bd24621488cb5435b1eff0',1,'com::sun::star::security::KeyUsage']]],
  ['key_5fdata_5falready_5fexist_44',['KEY_DATA_ALREADY_EXIST',['../namespacecom_1_1sun_1_1star_1_1xml_1_1crypto.html#ab5d887eb5da1173b766d96d0d863d1dcaa00107477b712be58b9ec9e95fee7629',1,'com::sun::star::xml::crypto']]],
  ['key_5fdata_5fnot_5ffound_45',['KEY_DATA_NOT_FOUND',['../namespacecom_1_1sun_1_1star_1_1xml_1_1crypto.html#ab5d887eb5da1173b766d96d0d863d1dca32b6dfd4835cda192446888bf21c62b9',1,'com::sun::star::xml::crypto']]],
  ['key_5fencipherment_46',['KEY_ENCIPHERMENT',['../namespacecom_1_1sun_1_1star_1_1security_1_1KeyUsage.html#a61450b1151c9b77bcb2c0fc89e53998d',1,'com::sun::star::security::KeyUsage']]],
  ['key_5fnot_5ffound_47',['KEY_NOT_FOUND',['../namespacecom_1_1sun_1_1star_1_1xml_1_1crypto.html#ab5d887eb5da1173b766d96d0d863d1dca9955d215de1c021927b7fb5ac43c97b4',1,'com::sun::star::xml::crypto']]],
  ['keychar_48',['KeyChar',['../structcom_1_1sun_1_1star_1_1awt_1_1KeyStroke.html#a2ebeaada4dee647dafd1cd26ea1a60c7',1,'com::sun::star::awt::KeyStroke::KeyChar()'],['../structcom_1_1sun_1_1star_1_1awt_1_1KeyEvent.html#a2ebeaada4dee647dafd1cd26ea1a60c7',1,'com::sun::star::awt::KeyEvent::KeyChar()']]],
  ['keycode_49',['KeyCode',['../structcom_1_1sun_1_1star_1_1awt_1_1KeyStroke.html#ac52fee1e96933f6d99789b325933a7ab',1,'com::sun::star::awt::KeyStroke::KeyCode()'],['../structcom_1_1sun_1_1star_1_1awt_1_1KeyEvent.html#ac52fee1e96933f6d99789b325933a7ab',1,'com::sun::star::awt::KeyEvent::KeyCode()']]],
  ['keycolumn_50',['KeyColumn',['../servicecom_1_1sun_1_1star_1_1sdbcx_1_1KeyColumn.html',1,'com::sun::star::sdbcx']]],
  ['keycolumn_2eidl_51',['KeyColumn.idl',['../KeyColumn_8idl.html',1,'']]],
  ['keycolumndescriptor_52',['KeyColumnDescriptor',['../servicecom_1_1sun_1_1star_1_1sdbcx_1_1KeyColumnDescriptor.html',1,'com::sun::star::sdbcx']]],
  ['keycolumndescriptor_2eidl_53',['KeyColumnDescriptor.idl',['../KeyColumnDescriptor_8idl.html',1,'']]],
  ['keydata_5fdisabled_54',['KEYDATA_DISABLED',['../namespacecom_1_1sun_1_1star_1_1xml_1_1crypto.html#ab5d887eb5da1173b766d96d0d863d1dca178176461322767cf1da68012c9cf9db',1,'com::sun::star::xml::crypto']]],
  ['keydescriptor_55',['KeyDescriptor',['../servicecom_1_1sun_1_1star_1_1sdbcx_1_1KeyDescriptor.html',1,'com::sun::star::sdbcx']]],
  ['keydescriptor_2eidl_56',['KeyDescriptor.idl',['../KeyDescriptor_8idl.html',1,'']]],
  ['keyevent_57',['KeyEvent',['../structcom_1_1sun_1_1star_1_1awt_1_1KeyEvent.html',1,'com::sun::star::awt']]],
  ['keyevent_2eidl_58',['KeyEvent.idl',['../KeyEvent_8idl.html',1,'']]],
  ['keyexception_59',['KeyException',['../exceptioncom_1_1sun_1_1star_1_1security_1_1KeyException.html',1,'com::sun::star::security']]],
  ['keyexception_2eidl_60',['KeyException.idl',['../KeyException_8idl.html',1,'']]],
  ['keyfunc_61',['KeyFunc',['../structcom_1_1sun_1_1star_1_1awt_1_1KeyEvent.html#a607ef284179388eaf7163586eaccafa4',1,'com::sun::star::awt::KeyEvent::KeyFunc()'],['../structcom_1_1sun_1_1star_1_1awt_1_1KeyStroke.html#a607ef284179388eaf7163586eaccafa4',1,'com::sun::star::awt::KeyStroke::KeyFunc()']]],
  ['keyfunction_2eidl_62',['KeyFunction.idl',['../KeyFunction_8idl.html',1,'']]],
  ['keygroup_2eidl_63',['KeyGroup.idl',['../KeyGroup_8idl.html',1,'']]],
  ['keyhole_64',['KEYHOLE',['../namespacecom_1_1sun_1_1star_1_1animations_1_1TransitionSubType.html#ac8c11e631b64563c2927cd482e0e357d',1,'com::sun::star::animations::TransitionSubType']]],
  ['keymodifier_2eidl_65',['KeyModifier.idl',['../KeyModifier_8idl.html',1,'']]],
  ['keyname_66',['KeyName',['../interfacecom_1_1sun_1_1star_1_1registry_1_1XRegistryKey.html#ad75286a69f558484322dac5297e2ed64',1,'com::sun::star::registry::XRegistryKey']]],
  ['keypress_67',['keyPress',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XToolkitRobot.html#a34d2d060fd1b98bc02fa62cda0b916f2',1,'com::sun::star::awt::XToolkitRobot']]],
  ['keypressed_68',['keyPressed',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XKeyHandler.html#a446f5df1e6a1f4668b6f3bb6a61274e0',1,'com::sun::star::awt::XKeyHandler::keyPressed()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XKeyListener.html#a23eec3c86bb38792c3b82e526833f8ef',1,'com::sun::star::awt::XKeyListener::keyPressed()']]],
  ['keyrelease_69',['keyRelease',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XToolkitRobot.html#a8a4602432c858937bc1de1ad954760f9',1,'com::sun::star::awt::XToolkitRobot']]],
  ['keyreleased_70',['keyReleased',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XKeyHandler.html#a3de04e2fa257684f9609b480b85cb4f9',1,'com::sun::star::awt::XKeyHandler::keyReleased()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XKeyListener.html#a55619b30c674cbe5283a84c7954dcd04',1,'com::sun::star::awt::XKeyListener::keyReleased()']]],
  ['keyrule_2eidl_71',['KeyRule.idl',['../KeyRule_8idl.html',1,'']]],
  ['keystroke_72',['KeyStroke',['../structcom_1_1sun_1_1star_1_1awt_1_1KeyStroke.html',1,'com::sun::star::awt']]],
  ['keystroke_2eidl_73',['KeyStroke.idl',['../KeyStroke_8idl.html',1,'']]],
  ['keytimes_74',['KeyTimes',['../interfacecom_1_1sun_1_1star_1_1animations_1_1XAnimate.html#a02aa546f990f8d460a8b1c78da3ba708',1,'com::sun::star::animations::XAnimate']]],
  ['keytype_75',['KeyType',['../interfacecom_1_1sun_1_1star_1_1container_1_1XMap.html#a30f2a87e0c20d8c997a6de03a3959683',1,'com::sun::star::container::XMap']]],
  ['keytype_2eidl_76',['KeyType.idl',['../KeyType_8idl.html',1,'']]],
  ['keyusage_2eidl_77',['KeyUsage.idl',['../KeyUsage_8idl.html',1,'']]],
  ['keywords_78',['Keywords',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1docinfo_1_1Keywords.html',1,'Keywords'],['../interfacecom_1_1sun_1_1star_1_1document_1_1XDocumentProperties.html#ab1ec921456fe6ab228469292cea71bf3',1,'com::sun::star::document::XDocumentProperties::Keywords()']]],
  ['keywords_2eidl_79',['Keywords.idl',['../Keywords_8idl.html',1,'']]],
  ['kgeneralpunctuation_80',['kGeneralPunctuation',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a7698d808c99f78a845b7c4eaa9794985',1,'com::sun::star::i18n']]],
  ['kgeometricshape_81',['kGeometricShape',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29acf8e174a2c18d9bdefea935630eb4094',1,'com::sun::star::i18n']]],
  ['kgeorgian_82',['kGeorgian',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29ac51d06968dee30d11d154713fea817a8',1,'com::sun::star::i18n']]],
  ['kgreek_83',['kGreek',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a245cce1fc7c52e8a2923edb33d8638ef',1,'com::sun::star::i18n']]],
  ['kgreekextended_84',['kGreekExtended',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a4e5899e29e78e9e2db42eb952e97145b',1,'com::sun::star::i18n']]],
  ['kgujarati_85',['kGujarati',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a0aea78516c89f111fcbf6e067ff9e533',1,'com::sun::star::i18n']]],
  ['kgurmukhi_86',['kGurmukhi',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29aef6d96f14761ec9853ebe677b7094fda',1,'com::sun::star::i18n']]],
  ['khalfwidthfullwidthform_87',['kHalfwidthFullwidthForm',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a1c36325bb9a4987f559b4d0f0a5aad8d',1,'com::sun::star::i18n']]],
  ['khangulcompatibilityjamo_88',['kHangulCompatibilityJamo',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a95b94bf35bf480589e7b4fffdf45639e',1,'com::sun::star::i18n']]],
  ['khanguljamo_89',['kHangulJamo',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a2c97d0cd44d9f172aa8a5e0c51fb2e08',1,'com::sun::star::i18n']]],
  ['khangulsyllable_90',['kHangulSyllable',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a37c9accd07ed64fe85efc29acee34033',1,'com::sun::star::i18n']]],
  ['khebrew_91',['kHebrew',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a395202dbd9cf346262b0def4c360aed0',1,'com::sun::star::i18n']]],
  ['khighprivateusesurrogate_92',['kHighPrivateUseSurrogate',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a03102ab55b19b32c05e7818b40858b0a',1,'com::sun::star::i18n']]],
  ['khighsurrogate_93',['kHighSurrogate',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29ac7c55e45349a1f81074fa6bd7a9f805c',1,'com::sun::star::i18n']]],
  ['khiragana_94',['kHiragana',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29ae7d10b9d3d8d9dd7b6839ce4b5d9458c',1,'com::sun::star::i18n']]],
  ['kideographicdescriptioncharacters_95',['kIdeographicDescriptionCharacters',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a475d76987d90c76ca3e7e7a8b58d8d99',1,'com::sun::star::i18n']]],
  ['kill_96',['kill',['../interfacecom_1_1sun_1_1star_1_1ucb_1_1XSimpleFileAccess.html#a524f97320c70ca8af65e2c5520a8cb37',1,'com::sun::star::ucb::XSimpleFileAccess']]],
  ['kind_5fdocument_97',['KIND_DOCUMENT',['../namespacecom_1_1sun_1_1star_1_1ucb_1_1ContentInfoAttribute.html#a17dc9b4d5d20df7676b55b537831c880',1,'com::sun::star::ucb::ContentInfoAttribute']]],
  ['kind_5ffolder_98',['KIND_FOLDER',['../namespacecom_1_1sun_1_1star_1_1ucb_1_1ContentInfoAttribute.html#accceefb8d791ac0f6ca9e03b1ebf867b',1,'com::sun::star::ucb::ContentInfoAttribute']]],
  ['kind_5flink_99',['KIND_LINK',['../namespacecom_1_1sun_1_1star_1_1ucb_1_1ContentInfoAttribute.html#a5acb4fb0a755945672e079704a70d2f4',1,'com::sun::star::ucb::ContentInfoAttribute']]],
  ['kipaextension_100',['kIPAExtension',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a38f1cce1222341bfe3366cc87d518af1',1,'com::sun::star::i18n']]],
  ['kkanbun_101',['kKanbun',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a6f82766f73f4ef3c6c6bfe3cf2981cc5',1,'com::sun::star::i18n']]],
  ['kkangxiradicals_102',['kKangxiRadicals',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29aedb5678722749aaec454b6ae1ba86f58',1,'com::sun::star::i18n']]],
  ['kkannada_103',['kKannada',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a6824169a9835865d022e39836e987b99',1,'com::sun::star::i18n']]],
  ['kkatakana_104',['kKatakana',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a7a35410c31ee2d1bdfbbbb62cc7288b8',1,'com::sun::star::i18n']]],
  ['kkhmer_105',['kKhmer',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a5eafa835bf81e0076a9765fb29624d90',1,'com::sun::star::i18n']]],
  ['klao_106',['kLao',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29ace56c2ba76cbbad5927d8d76df33bcc3',1,'com::sun::star::i18n']]],
  ['klatin1supplement_107',['kLatin1Supplement',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a404119a810031b38f250373aef317a94',1,'com::sun::star::i18n']]],
  ['klatinextendeda_108',['kLatinExtendedA',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a6d82badeb5506e093f3635d792d7f02c',1,'com::sun::star::i18n']]],
  ['klatinextendedadditional_109',['kLatinExtendedAdditional',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a0200f227ed1b9cf72b0744e625949d58',1,'com::sun::star::i18n']]],
  ['klatinextendedb_110',['kLatinExtendedB',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29ab299675366822220d74165dd6e8250bf',1,'com::sun::star::i18n']]],
  ['kletterlikesymbol_111',['kLetterlikeSymbol',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a47de50de96a980c0ae0611d2fb433ad5',1,'com::sun::star::i18n']]],
  ['klowsurrogate_112',['kLowSurrogate',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a2c6bddacbaa071fba9aab799d6fcc345',1,'com::sun::star::i18n']]],
  ['km_113',['KM',['../namespacecom_1_1sun_1_1star_1_1util_1_1MeasureUnit.html#a283d542e141c7362a5ac415a9789887a',1,'com::sun::star::util::MeasureUnit']]],
  ['kmalayalam_114',['kMalayalam',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a2b0716cc801f11448f3e19412f269940',1,'com::sun::star::i18n']]],
  ['kmathoperator_115',['kMathOperator',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a1650a668a3c2345e9b51c10f6f1fdb52',1,'com::sun::star::i18n']]],
  ['kmiscsymbol_116',['kMiscSymbol',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a762f48b9ca052d278f3b7fd4b92a2671',1,'com::sun::star::i18n']]],
  ['kmisctechnical_117',['kMiscTechnical',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a7cefb8b67bf0695982df93df742c1ecd',1,'com::sun::star::i18n']]],
  ['kmongolian_118',['kMongolian',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a76890ee813b9359237ca97d51dfcc4fb',1,'com::sun::star::i18n']]],
  ['kmyanmar_119',['kMyanmar',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a3a07b748d9c3caa948debc5d5814cc50',1,'com::sun::star::i18n']]],
  ['knoscript_120',['kNoScript',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a98acbc41bab46847d99ac95c8f02ac0e',1,'com::sun::star::i18n']]],
  ['knumberform_121',['kNumberForm',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29aa30533d5a56be3dade883b69755e609a',1,'com::sun::star::i18n']]],
  ['knumberformattype_2eidl_122',['KNumberFormatType.idl',['../KNumberFormatType_8idl.html',1,'']]],
  ['knumberformatusage_2eidl_123',['KNumberFormatUsage.idl',['../KNumberFormatUsage_8idl.html',1,'']]],
  ['kogham_124',['kOgham',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a7641a97b57cfc399cad12f3a21997c8f',1,'com::sun::star::i18n']]],
  ['kopticalcharacter_125',['kOpticalCharacter',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29aaff7560b4e76c3f33c3981a6078b14f8',1,'com::sun::star::i18n']]],
  ['koriya_126',['kOriya',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29aba86aa014c3c2f0c33e4856fa870291a',1,'com::sun::star::i18n']]],
  ['kparsetokens_2eidl_127',['KParseTokens.idl',['../KParseTokens_8idl.html',1,'']]],
  ['kparsetype_2eidl_128',['KParseType.idl',['../KParseType_8idl.html',1,'']]],
  ['kprivateuse_129',['kPrivateUse',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a8d537e60fa10307576e8a3cb16a82c73',1,'com::sun::star::i18n']]],
  ['krunic_130',['kRunic',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29ad34ac9d0d8ff007b3d547f49e846abb8',1,'com::sun::star::i18n']]],
  ['kscriptcount_131',['kScriptCount',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29ab6c696183279042cec9e2a534fa55a6a',1,'com::sun::star::i18n']]],
  ['ksinhala_132',['kSinhala',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29afc5d0f94ad77d121198f06f66b2fed9d',1,'com::sun::star::i18n']]],
  ['ksmallformvariant_133',['kSmallFormVariant',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a1208c4be4ff8bc85e2f2f0b2470935d1',1,'com::sun::star::i18n']]],
  ['kspacingmodifier_134',['kSpacingModifier',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a739e1ecb5d01be1a779a53a7405d6bd3',1,'com::sun::star::i18n']]],
  ['ksupersubscript_135',['kSuperSubScript',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a1f8dbee1293dfbc3b59711ccc28e0dcd',1,'com::sun::star::i18n']]],
  ['ksymbolcombiningmark_136',['kSymbolCombiningMark',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a8c40a0964b9675be7769aa0fed797258',1,'com::sun::star::i18n']]],
  ['ksyriac_137',['kSyriac',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a2bc820dedf31f5bc23c729e84726a41c',1,'com::sun::star::i18n']]],
  ['ktamil_138',['kTamil',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a304e6a3feb5a87f68acb9764a0e3aa58',1,'com::sun::star::i18n']]],
  ['ktelugu_139',['kTelugu',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a082333c2d568d9efbda40f0ebe4da5ac',1,'com::sun::star::i18n']]],
  ['kthaana_140',['kThaana',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a47f95d32146e21b25e2170f39c45eb71',1,'com::sun::star::i18n']]],
  ['kthai_141',['kThai',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a4d3ef658a35504e7d13b19f8bd0bfcd9',1,'com::sun::star::i18n']]],
  ['ktibetan_142',['kTibetan',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29a56bfc5ffb5d90e82a6a18733281f3660',1,'com::sun::star::i18n']]],
  ['kunifiedcanadianaboriginalsyllabics_143',['kUnifiedCanadianAboriginalSyllabics',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29ac8d16577ca711b492a62284d5f5f06fe',1,'com::sun::star::i18n']]],
  ['kyiradicals_144',['kYiRadicals',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29acff3281626fd6f7fb51624ace03cc30a',1,'com::sun::star::i18n']]],
  ['kyisyllables_145',['kYiSyllables',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a47be7d1d06e067d647f387cc160d5e29ad97520d3ce13c865077f4ab2e67d8f7f',1,'com::sun::star::i18n']]]
];
